NeumorphismStyle class

Constructors

NeumorphismStyle({Color color = const Color(0xFFE8EDF2), double borderRadius = 16.0, double depth = 8.0, NeumorphismType type = NeumorphismType.flat, BoxShape shape = BoxShape.rectangle, Color? lightShadow, Color? darkShadow})
const

Properties

borderRadius double
final
color Color
final
darkShadow Color?
Overrides the auto-computed dark shadow color.
final
depth double
Shadow depth — controls offset & blur. Range: 0–20. Default: 8.
final
hashCode int
The hash code for this object.
no setterinherited
lightShadow Color?
Overrides the auto-computed highlight shadow color.
final
resolvedDark Color
no setter
resolvedLight Color
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape BoxShape
final
type NeumorphismType
final

Methods

copyWith({Color? color, double? borderRadius, double? depth, NeumorphismType? type, BoxShape? shape, Color? lightShadow, Color? darkShadow}) NeumorphismStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited